@@ -41,15 +41,7 @@ def tokfile(token: str = None):
         root.update()
         gtt = simpledialog.askstring('', 'Token:', parent = root, show = '*')
         if gtt:
-            ask = messagebox.askyesno('', 'Do you want set token to variable environment?', parent = root)
-            root.destroy()            
-            if ask:
-                clien.cmsk(gtt, vr, vr.lower().replace('_',''))
-                print('Please restart Console for var to work!')
-                sys.exit()
-            else:
-                print('Token not set to variable environment!')
-            ky = gtt
+            clien.cmsk(gtt, vr, vr.lower().replace('_',''))
         else:
             print('No token, aborted!')
             
